| ExposureCurveLNorm | R Documentation |
Gives the share of the expected claim cost of a LogNormal severity distribution that falls below the amount x (the capped mean divided by the mean), as used to exposure rate a layer.
ExposureCurveLNorm(x, mu, sigma)
x |
A non-negative real number - the claim amount where the exposure curve will be evaluated. |
mu |
A real number - the first parameter of the Claim Severity's LogNormal distribution. |
sigma |
A positive real number - the second parameter of the Claim Severity's LogNormal distribution. |
The value of the Exposure curve at x with Claim Severity from a LogNormal distribution with parameters mu and sigma. An infinite x gives 1. The arguments are recycled to a common length. A non-numeric argument, a negative x or a non-positive sigma is an error; NA values give NA.
Other exposure curve functions:
ExposureCurveGamma(),
ExposureCurvePareto(),
ExposureCurveSlicedGammaPareto(),
ExposureCurveSlicedLNormPareto()
ExposureCurveLNorm(2000,6,1.5)
ExposureCurveLNorm(1000,5,1.6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.