| ExposureCurvePareto | R Documentation |
Gives the share of the expected claim cost of a Pareto severity distribution that falls below the amount x (the capped mean divided by the mean), as used to exposure rate a layer.
ExposureCurvePareto(x, scale, shape)
x |
A non-negative real number - the claim amount where the exposure curve will be evaluated. |
scale |
A positive real number - the scale parameter of the Claim Severity's Pareto distribution. |
shape |
A positive real number - the shape parameter of the Claim Severity's Pareto distribution. |
The value of the Exposure curve at x with Claim Severity from a Pareto distribution with parameters scale and shape. The exposure curve divides by the mean, which is infinite when shape <= 1; the function returns 0 in that case.
Other exposure curve functions:
ExposureCurveGamma(),
ExposureCurveLNorm(),
ExposureCurveSlicedGammaPareto(),
ExposureCurveSlicedLNormPareto()
ExposureCurvePareto(700,500,1.2)
ExposureCurvePareto(20000,200,1.1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.