ExposureCurveSlicedLNormPareto: Exposure Curve from a Sliced LogNormal Pareto severity...

View source: R/SlicecdLogNormalPareto.R

ExposureCurveSlicedLNormParetoR Documentation

Exposure Curve from a Sliced LogNormal Pareto severity distribution

Description

Gives the share of the expected claim cost of a sliced LogNormal-Pareto severity distribution that falls below the amount x (the capped mean divided by the mean), as used to exposure rate a layer.

Usage

ExposureCurveSlicedLNormPareto(x, mu, sigma, SlicePoint, shape)

Arguments

x

A non-negative real number - the claim amount where the exposure curve will be evaluated.

mu

A real number - the first parameter of the attritional Claim Severity's LogNormal distribution.

sigma

A positive real number - the second parameter of the attritional Claim Severity's LogNormal distribution.

SlicePoint

A positive real number - the slice point and the scale parameter of the tail Claim Severity's Pareto distribution. An infinite slice point gives the LogNormal distribution.

shape

A positive real number - the shape parameter of the tail Claim Severity's Pareto distribution.

Details

shape is the Pareto shape parameter, usually written alpha; the sliced Gamma-Pareto functions call the same parameter PShape.

Value

The value of the Exposure curve at x with an attritional claim LogNormal distribution with parameters mu and sigma and a large claim Pareto distribution with parameters SlicePoint and shape. The exposure curve divides by the mean, which is infinite when shape <= 1 (and SlicePoint is finite); the function returns 0 in that case.

See Also

Other exposure curve functions: ExposureCurveGamma(), ExposureCurveLNorm(), ExposureCurvePareto(), ExposureCurveSlicedGammaPareto()

Examples

ExposureCurveSlicedLNormPareto(1200,6,1.5,1000,1.2)
ExposureCurveSlicedLNormPareto(4000,7,1.6,3000,1.4)

NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.