GLMFittingToolServer: Server function for the GLM Fitting tool application

View source: R/GLMFittingToolServer.R

GLMFittingToolServerR Documentation

Server function for the GLM Fitting tool application

Description

Runs a session of the GLM fitting tool: imports the data, fits the models, compares the stored ones, draws the actual against predicted chart and saves and loads the settings.

Usage

GLMFittingToolServer(input, output, session)

Arguments

input

Input for the server function.

output

Output for the server function.

session

Session for the server function.

Value

Called by shiny for its side effects, the outputs and observers of a session; the value is not used.


NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.