GLMFittingToolUI: User interface of the Shiny GLM fitting tool

View source: R/GLMFittingToolUI.R

GLMFittingToolUIR Documentation

User interface of the Shiny GLM fitting tool

Description

Builds the pages of the GLM fitting tool: Welcome, Data, Model, Actual vs predicted and Save & load, with the theme switch.

Usage

GLMFittingToolUI(request)

Arguments

request

The request, supplied by shiny.

Details

A function of the request, so that it is built when the app starts, after every helper of the package is defined.

Value

The user interface of the application, a bslib navbar page.


NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.