GammaCappedMean: Gamma capped mean

View source: R/Gamma.R

GammaCappedMeanR Documentation

Gamma capped mean

Description

Gives the expected claim amount when each claim from a Gamma severity distribution is capped at cap, as needed to price a policy limit or a reinsurance layer.

Usage

GammaCappedMean(cap, shape, rate)

Arguments

cap

A non-negative real number - the claim severity cap.

shape

A positive real number - the shape parameter of the Claim Severity's Gamma distribution.

rate

A positive real number - the rate parameter of the Claim Severity's Gamma distribution.

Value

The mean of the claim severity capped at cap with a Gamma distribution with parameters shape and rate. The arguments are recycled to a common length. A non-numeric argument, a negative cap or a non-positive shape or rate is an error; NA values give NA.

See Also

Other capped mean functions: LNormCappedMean(), ParetoCappedMean(), ParetoCappedMeanCalc(), SlicedGammaParetoCappedMean(), SlicedLNormParetoCappedMean()

Examples

GammaCappedMean(700,1,0.0005)
GammaCappedMean(1000,1.5,0.0006)

NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.