IGamma: Upper incomplete gamma function

View source: R/Gamma.R

IGammaR Documentation

Upper incomplete gamma function

Description

Evaluates the upper incomplete gamma function, the integral of t^(a - 1) * exp(-t) from x to infinity, which appears in the closed form of the Gamma capped mean.

Usage

IGamma(a, x)

Arguments

a

A positive real number - the shape parameter.

x

A non-negative real number.

Value

The value of the upper incomplete gamma function at x with shape parameter a, i.e. gamma(a) * pgamma(x, a, lower.tail = FALSE). The arguments are recycled to a common length. A non-numeric or non-positive a or a negative x is an error.

See Also

GammaCappedMean

Examples

IGamma(1,1)
IGamma(0.1,2)

NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.