ILFLNorm: Increased Limit Factor Curve from a LogNormal severity...

View source: R/LogNormal.R

ILFLNormR Documentation

Increased Limit Factor Curve from a LogNormal severity distribution

Description

Gives the ratio of the LogNormal capped mean at xHigh to that at xLow, the factor that takes the expected cost of a policy limit of xLow to that of a limit of xHigh.

Usage

ILFLNorm(xLow, xHigh, mu, sigma)

Arguments

xLow

A non-negative real number - the claim amount where the Increased Limit Factor Curve will be evaluated from.

xHigh

A non-negative real number - the claim amount where the Increased Limit Factor Curve will be evaluated to.

mu

A real number - the first parameter of the Claim Severity's LogNormal distribution.

sigma

A positive real number - the second parameter of the Claim Severity's LogNormal distribution.

Value

The value of the Increased Limit Factor curve from xLow to xHigh with Claim Severity from a LogNormal distribution with parameters mu and sigma.

See Also

Other ILF functions: ILFGamma(), ILFPareto(), ILFSlicedGammaPareto(), ILFSlicedLNormPareto()

Examples

ILFLNorm(1000,2000,6,1.5)
ILFLNorm(1000,1500,5,1.6)

NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.