LNormCappedMean: Lognormal capped mean

View source: R/LogNormal.R

LNormCappedMeanR Documentation

Lognormal capped mean

Description

Gives the expected claim amount when each claim from a LogNormal severity distribution is capped at cap, as needed to price a policy limit or a reinsurance layer.

Usage

LNormCappedMean(cap, mu, sigma)

Arguments

cap

A non-negative real number - the claim severity cap.

mu

A real number - the first parameter of the Claim Severity's LogNormal distribution.

sigma

A positive real number - the second parameter of the Claim Severity's LogNormal distribution.

Value

The mean of the claim severity capped at cap with a LogNormal distribution with parameters mu and sigma. The arguments are recycled to a common length. A non-numeric argument, a negative cap or a non-positive sigma is an error; NA values give NA.

See Also

Other capped mean functions: GammaCappedMean(), ParetoCappedMean(), ParetoCappedMeanCalc(), SlicedGammaParetoCappedMean(), SlicedLNormParetoCappedMean()

Examples

LNormCappedMean(2000,6,1.5)
LNormCappedMean(1000,5,1.6)

NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.