freq_dist_parameter_placeholders: A data frame with the frequency distribution parameter...

freq_dist_parameter_placeholdersR Documentation

A data frame with the frequency distribution parameter placeholders

Description

One row per parameter of the frequency distribution with the most parameters, giving the number and output id of the placeholder in which the simulator app renders that parameter's input for the chosen distribution.

Usage

freq_dist_parameter_placeholders

Value

The frequency distribution parameter placeholders.


NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.