max_number_of_pareto_slices: Parameter to set the maximum number of Pareto slices

max_number_of_pareto_slicesR Documentation

Parameter to set the maximum number of Pareto slices

Description

The largest number of Pareto slices that the simulator app and simulate_claims accept, so that the app can build one row of slice inputs for each.

Usage

max_number_of_pareto_slices

Value

The maximum number of Pareto Slices.


NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.