pSlicedLNormPareto: The cumulative distribution function (cdf) of a Sliced...

View source: R/SlicecdLogNormalPareto.R

pSlicedLNormParetoR Documentation

The cumulative distribution function (cdf) of a Sliced LogNormal Pareto severity distribution

Description

Gives the probability that a claim from a sliced severity distribution, with LogNormal attritional claims below the slice point and a Pareto tail above it, is at most x.

Usage

pSlicedLNormPareto(x, mu, sigma, SlicePoint, shape)

Arguments

x

A real number - the claim amount where the cumulative distribution function (cdf) will be evaluated. The cdf is 0 for negative x.

mu

A real number - the first parameter of the attritional Claim Severity's LogNormal distribution.

sigma

A positive real number - the second parameter of the attritional Claim Severity's LogNormal distribution.

SlicePoint

A positive real number - the slice point and the scale parameter of the tail Claim Severity's Pareto distribution. An infinite slice point gives the LogNormal distribution.

shape

A positive real number - the shape parameter of the tail Claim Severity's Pareto distribution.

Details

shape is the Pareto shape parameter, usually written alpha; the sliced Gamma-Pareto functions call the same parameter PShape.

Value

The value of the cumulative distribution function (cdf) at x with an attritional claim LogNormal distribution with parameters mu and sigma and a large claim Pareto distribution with parameters SlicePoint and shape. A non-numeric argument or a non-positive sigma, SlicePoint or shape is an error; NA values give NA.

See Also

Other sliced distribution functions: SlicedGammaParetoMean(), SlicedLNormParetoMean(), dSlicedGammaPareto(), dSlicedLNormPareto(), pSlicedGammaPareto(), qSlicedGammaPareto(), qSlicedLNormPareto()

Examples

pSlicedLNormPareto(1200,6,1.5,1000,1.2)
pSlicedLNormPareto(4000,7,1.6,3000,1.4)

NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.