reinsurance_structures_options: A vector with the reinsurance structure options

reinsurance_structures_optionsR Documentation

A vector with the reinsurance structure options

Description

The names of the reinsurance structures that apply_deductible_limit and simulate_function accept, used by the simulator app as the choices of its structure inputs and to validate saved settings.

Usage

reinsurance_structures_options

Value

The reinsurance structure options


NetSimR documentation built on Sept. 30, 2026, 5:13 p.m.