| ExposureCurveGamma | R Documentation |
Gives the share of the expected claim cost of a Gamma severity distribution that falls below the amount x (the capped mean divided by the mean), as used to exposure rate a layer.
ExposureCurveGamma(x, shape, rate)
x |
A non-negative real number - the claim amount where the exposure curve will be evaluated. |
shape |
A positive real number - the shape parameter of the Claim Severity's Gamma distribution. |
rate |
A positive real number - the rate parameter of the Claim Severity's Gamma distribution. |
The value of the Exposure curve at x with Claim Severity from a Gamma distribution with parameters shape and rate. The arguments are recycled to a common length. A non-numeric argument, a negative x or a non-positive shape or rate is an error; NA values give NA.
Other exposure curve functions:
ExposureCurveLNorm(),
ExposureCurvePareto(),
ExposureCurveSlicedGammaPareto(),
ExposureCurveSlicedLNormPareto()
ExposureCurveGamma(700,1,0.0005)
ExposureCurveGamma(1000,1.5,0.0006)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.