View source: R/SlicecdGammaPareto.R
| ExposureCurveSlicedGammaPareto | R Documentation |
Gives the share of the expected claim cost of a sliced Gamma-Pareto severity distribution that falls below the amount x (the capped mean divided by the mean), as used to exposure rate a layer.
ExposureCurveSlicedGammaPareto(x, GShape, GRate, SlicePoint, PShape)
x |
A non-negative real number - the claim amount where the exposure curve will be evaluated. |
GShape |
A positive real number - the shape parameter of the Claim Severity's Gamma distribution. |
GRate |
A positive real number - the rate parameter of the Claim Severity's Gamma distribution. |
SlicePoint |
A positive real number - the slice point and the scale parameter of the Claim Severity's Pareto distribution. An infinite slice point gives the Gamma distribution. |
PShape |
A positive real number - the shape parameter of the Claim Severity's Pareto distribution. |
PShape is the Pareto shape parameter, usually written alpha; the sliced LogNormal-Pareto functions call the same parameter shape.
The value of the Exposure curve at x with an attritional claim Gamma distribution with parameters GShape and GRate and a large claim Pareto distribution with parameters SlicePoint and PShape. The exposure curve divides by the mean, which is infinite when PShape <= 1 (and SlicePoint is finite); the function returns 0 in that case.
Other exposure curve functions:
ExposureCurveGamma(),
ExposureCurveLNorm(),
ExposureCurvePareto(),
ExposureCurveSlicedLNormPareto()
ExposureCurveSlicedGammaPareto(3000,1,0.0005,1000,1.2)
ExposureCurveSlicedGammaPareto(1000,1.1,0.0006,2000,1.6)
ExposureCurveSlicedGammaPareto(2000,1.2,0.0004,3000,1.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.