View source: R/GLMFittingToolServer.R
| GLMFittingToolServer | R Documentation |
Runs a session of the GLM fitting tool: imports the data, fits the models, compares the stored ones, draws the actual against predicted chart and saves and loads the settings.
GLMFittingToolServer(input, output, session)
input |
Input for the server function. |
output |
Output for the server function. |
session |
Session for the server function. |
Called by shiny for its side effects, the outputs and observers of a session; the value is not used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.