View source: R/GLMFittingToolUI.R
| GLMFittingToolUI | R Documentation |
Builds the pages of the GLM fitting tool: Welcome, Data, Model, Actual vs predicted and Save & load, with the theme switch.
GLMFittingToolUI(request)
request |
The request, supplied by shiny. |
A function of the request, so that it is built when the app starts, after every helper of the package is defined.
The user interface of the application, a bslib navbar page.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.