GLMFittingToolUI: User interface of the Shiny GLM fitting tool

View source: R/GLMFittingToolUI.R

GLMFittingToolUIR Documentation

User interface of the Shiny GLM fitting tool

Description

A function of the request, so that it is built when the app starts, after every helper of the package is defined.

Usage

GLMFittingToolUI(request)

Arguments

request

The request, supplied by shiny.

Value

The user interface of the application, a bslib navbar page.


NetSimR documentation built on Sept. 14, 2026, 1:07 a.m.