View source: R/GLMFittingToolUI.R
| GLMFittingToolUI | R Documentation |
A function of the request, so that it is built when the app starts, after every helper of the package is defined.
GLMFittingToolUI(request)
request |
The request, supplied by shiny. |
The user interface of the application, a bslib navbar page.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.