| IGamma | R Documentation |
Evaluates the upper incomplete gamma function, the integral of t^(a - 1) * exp(-t) from x to infinity, which appears in the closed form of the Gamma capped mean.
IGamma(a, x)
a |
A positive real number - the shape parameter. |
x |
A non-negative real number. |
The value of the upper incomplete gamma function at x with shape parameter a, i.e. gamma(a) * pgamma(x, a, lower.tail = FALSE). The arguments are recycled to a common length. A non-numeric or non-positive a or a negative x is an error.
GammaCappedMean
IGamma(1,1)
IGamma(0.1,2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.