| LNormCappedMean | R Documentation |
Gives the expected claim amount when each claim from a LogNormal severity distribution is capped at cap, as needed to price a policy limit or a reinsurance layer.
LNormCappedMean(cap, mu, sigma)
cap |
A non-negative real number - the claim severity cap. |
mu |
A real number - the first parameter of the Claim Severity's LogNormal distribution. |
sigma |
A positive real number - the second parameter of the Claim Severity's LogNormal distribution. |
The mean of the claim severity capped at cap with a LogNormal distribution with parameters mu and sigma. The arguments are recycled to a common length. A non-numeric argument, a negative cap or a non-positive sigma is an error; NA values give NA.
Other capped mean functions:
GammaCappedMean(),
ParetoCappedMean(),
ParetoCappedMeanCalc(),
SlicedGammaParetoCappedMean(),
SlicedLNormParetoCappedMean()
LNormCappedMean(2000,6,1.5)
LNormCappedMean(1000,5,1.6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.