| ParetoCappedMeanCalc | R Documentation |
Evaluates the closed-form expression (shape * scale - cap * (scale / cap)^shape) / (shape - 1) that the Pareto capped mean is built on, for checking or reusing the intermediate step.
ParetoCappedMeanCalc(cap, scale, shape)
cap |
A non-negative real number - the claim severity cap. |
scale |
A positive real number - the scale parameter of the Claim Severity's Pareto distribution. |
shape |
A positive real number - the shape parameter of the Claim Severity's Pareto distribution. |
An interim calculation for the mean of the claim severity capped at cap with a Pareto distribution with parameters scale and shape. It is the closed form for cap >= scale and shape != 1; use ParetoCappedMean for the capped mean itself. The arguments are recycled to a common length.
Other capped mean functions:
GammaCappedMean(),
LNormCappedMean(),
ParetoCappedMean(),
SlicedGammaParetoCappedMean(),
SlicedLNormParetoCappedMean()
ParetoCappedMeanCalc(800,100,1.1)
ParetoCappedMeanCalc(1000,500,0.9)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.