ParetoCappedMeanCalc: Pareto capped mean intermediary calculation

View source: R/Pareto.R

ParetoCappedMeanCalcR Documentation

Pareto capped mean intermediary calculation

Description

Pareto capped mean intermediary calculation

Usage

ParetoCappedMeanCalc(cap, scale, shape)

Arguments

cap

A positive real number - the claim severity cap.

scale

A positive real number - the scale parameter of the Claim Severity's Pareto distribution.

shape

A positive real number - the shape parameter of the Claim Severity's Pareto distribution.

Value

An interim calculation for the mean of the claim severity capped at cap with a Pareto distribution with parameters scale and shape. It is the closed form for cap >= scale and shape != 1; use ParetoCappedMean for the capped mean itself.

Examples

ParetoCappedMeanCalc(800,100,1.1)
ParetoCappedMeanCalc(1000,500,0.9)

NetSimR documentation built on Sept. 14, 2026, 1:07 a.m.