View source: R/SlicecdGammaPareto.R
| SlicedGammaParetoCappedMean | R Documentation |
Gives the expected claim amount when each claim from a sliced severity distribution, with Gamma attritional claims below the slice point and a Pareto tail above it, is capped at cap.
SlicedGammaParetoCappedMean(cap, GShape, GRate, SlicePoint, PShape)
cap |
A non-negative real number - the claim severity cap. |
GShape |
A positive real number - the shape parameter of the attritional Claim Severity's Gamma distribution. |
GRate |
A positive real number - the rate parameter of the attritional Claim Severity's Gamma distribution. |
SlicePoint |
A positive real number - the slice point and the scale parameter of the tail Claim Severity's Pareto distribution. An infinite slice point gives the Gamma distribution. |
PShape |
A positive real number - the shape parameter of the tail Claim Severity's Pareto distribution. |
PShape is the Pareto shape parameter, usually written alpha; the sliced LogNormal-Pareto functions call the same parameter shape.
The mean of the claim severity capped at cap with an attritional claim Gamma distribution with parameters GShape and GRate and a large claim Pareto distribution with parameters SlicePoint and PShape. A non-numeric argument, a negative cap or a non-positive parameter is an error; NA values give NA.
Other capped mean functions:
GammaCappedMean(),
LNormCappedMean(),
ParetoCappedMean(),
ParetoCappedMeanCalc(),
SlicedLNormParetoCappedMean()
SlicedGammaParetoCappedMean(3000,1,0.0005,1000,1.2)
SlicedGammaParetoCappedMean(1000,1.1,0.0006,2000,1.6)
SlicedGammaParetoCappedMean(2000,1.2,0.0004,3000,1.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.