View source: R/SlicecdLogNormalPareto.R
| dSlicedLNormPareto | R Documentation |
Gives the probability density at the claim amount x of a sliced severity distribution, with LogNormal attritional claims below the slice point and a Pareto tail above it.
dSlicedLNormPareto(x, mu, sigma, SlicePoint, shape)
x |
A real number - the claim amount where the probability density function (pdf) will be evaluated. The pdf is 0 for negative |
mu |
A real number - the first parameter of the attritional Claim Severity's LogNormal distribution. |
sigma |
A positive real number - the second parameter of the attritional Claim Severity's LogNormal distribution. |
SlicePoint |
A positive real number - the slice point and the scale parameter of the Claim Severity's Pareto distribution. An infinite slice point gives the LogNormal distribution. |
shape |
A positive real number - the shape parameter of the Claim Severity's Pareto distribution. |
shape is the Pareto shape parameter, usually written alpha; the sliced Gamma-Pareto functions call the same parameter PShape.
The value of the probability density function (pdf) at x with an attritional claim LogNormal distribution with parameters mu and sigma and a large claim Pareto distribution with parameters SlicePoint and shape. A non-numeric argument or a non-positive sigma, SlicePoint or shape is an error; NA values give NA.
Other sliced distribution functions:
SlicedGammaParetoMean(),
SlicedLNormParetoMean(),
dSlicedGammaPareto(),
pSlicedGammaPareto(),
pSlicedLNormPareto(),
qSlicedGammaPareto(),
qSlicedLNormPareto()
dSlicedLNormPareto(1200,6,1.5,1000,1.2)
dSlicedLNormPareto(4000,7,1.6,3000,1.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.