distribution_fitting_tool_UI: User interface of the Shiny distribution fitting tool

distribution_fitting_tool_UIR Documentation

User interface of the Shiny distribution fitting tool

Description

The page is built when the package is installed; run_shiny_distribution_fitting_tool() pairs it with distribution_fitting_tool_Server.

Usage

distribution_fitting_tool_UI

Value

The user interface of the application, a bslib navbar page.


NetSimR documentation built on Sept. 14, 2026, 1:07 a.m.