| distribution_fitting_tool_UI | R Documentation |
The page is built when the package is installed; run_shiny_distribution_fitting_tool() pairs it with distribution_fitting_tool_Server.
distribution_fitting_tool_UI
The user interface of the application, a bslib navbar page.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.