| max_number_of_pareto_slices | R Documentation |
The largest number of Pareto slices that the simulator app and
simulate_claims accept, so that the app can build one row of slice inputs
for each.
max_number_of_pareto_slices
The maximum number of Pareto Slices.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.