max_number_of_pareto_slices: Parameter to set the maximum number of pareto slices
Description
Parameter to set the maximum number of pareto slices
Usage
max_number_of_pareto_slices
Value
The the maximum number of Pareto Slices.
Format
An object of class numeric of length 1.