View source: R/SlicecdLogNormalPareto.R
| pSlicedLNormPareto | R Documentation |
Gives the probability that a claim from a sliced severity distribution, with LogNormal attritional claims below the slice point and a Pareto tail above it, is at most x.
pSlicedLNormPareto(x, mu, sigma, SlicePoint, shape)
x |
A real number - the claim amount where the cumulative distribution function (cdf) will be evaluated. The cdf is 0 for negative |
mu |
A real number - the first parameter of the attritional Claim Severity's LogNormal distribution. |
sigma |
A positive real number - the second parameter of the attritional Claim Severity's LogNormal distribution. |
SlicePoint |
A positive real number - the slice point and the scale parameter of the tail Claim Severity's Pareto distribution. An infinite slice point gives the LogNormal distribution. |
shape |
A positive real number - the shape parameter of the tail Claim Severity's Pareto distribution. |
shape is the Pareto shape parameter, usually written alpha; the sliced Gamma-Pareto functions call the same parameter PShape.
The value of the cumulative distribution function (cdf) at x with an attritional claim LogNormal distribution with parameters mu and sigma and a large claim Pareto distribution with parameters SlicePoint and shape. A non-numeric argument or a non-positive sigma, SlicePoint or shape is an error; NA values give NA.
Other sliced distribution functions:
SlicedGammaParetoMean(),
SlicedLNormParetoMean(),
dSlicedGammaPareto(),
dSlicedLNormPareto(),
pSlicedGammaPareto(),
qSlicedGammaPareto(),
qSlicedLNormPareto()
pSlicedLNormPareto(1200,6,1.5,1000,1.2)
pSlicedLNormPareto(4000,7,1.6,3000,1.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.