The value of the inverse cumulative density function at q with an attritional claim Gamma distribution with parameters GShape and GRate and a large claim Pareto distribution with parameters SlicePoint and PShape.
Arguments
q
A real number between 0 and 1 - the probability where the inverse cumulative density function will be evaluated.
GShape
A positive real number - the shape parameter of the attritional Claim Severity's Gamma distribution.
GRate
A positive real number - the rate parameter of the attritional Claim Severity's Gamma distribution.
SlicePoint
A positive real number - the slice point and the scale parameter of the tail Claim Severity's Pareto distribution.
PShape
A positive real number - the shape parameter of the tail Claim Severity's Pareto distribution.