View source: R/SlicecdLogNormalPareto.R
| qSlicedLNormPareto | R Documentation |
Gives the claim amount that a claim from a sliced severity distribution, with LogNormal attritional claims below the slice point and a Pareto tail above it, stays at or below with probability q; the inverse of pSlicedLNormPareto.
qSlicedLNormPareto(q, mu, sigma, SlicePoint, shape)
q |
A real number between 0 and 1 - the probability where the inverse cumulative distribution function will be evaluated. Values outside [0, 1] give |
mu |
A real number - the first parameter of the attritional Claim Severity's LogNormal distribution. |
sigma |
A positive real number - the second parameter of the attritional Claim Severity's LogNormal distribution. |
SlicePoint |
A positive real number - the slice point and the scale parameter of the tail Claim Severity's Pareto distribution. An infinite slice point gives the LogNormal distribution. |
shape |
A positive real number - the shape parameter of the tail Claim Severity's Pareto distribution. |
shape is the Pareto shape parameter, usually written alpha; the sliced Gamma-Pareto functions call the same parameter PShape.
The value of the inverse cumulative distribution function at q with an attritional claim LogNormal distribution with parameters mu and sigma and a large claim Pareto distribution with parameters SlicePoint and shape. A non-numeric argument or a non-positive sigma, SlicePoint or shape is an error; NA values give NA.
Other sliced distribution functions:
SlicedGammaParetoMean(),
SlicedLNormParetoMean(),
dSlicedGammaPareto(),
dSlicedLNormPareto(),
pSlicedGammaPareto(),
pSlicedLNormPareto(),
qSlicedGammaPareto()
qSlicedLNormPareto(0.5,6,1.5,1000,1.2)
qSlicedLNormPareto(0.7,7,1.6,3000,1.4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.