View source: R/distribution_fitting_tool_global.R
| run_shiny_distribution_fitting_tool | R Documentation |
A function to run the distribution fitting tool application
run_shiny_distribution_fitting_tool()
A shiny app object. Printing it, as happens when the function is called at the console, opens the application; it can also be passed to shiny::runApp().
if (interactive()) {
run_shiny_distribution_fitting_tool()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.