| sev_dist_parameter_placeholders | R Documentation |
One row per parameter of the severity distribution with the most parameters, giving the number and output id of the placeholder in which the simulator app renders that parameter's input for the chosen distribution.
sev_dist_parameter_placeholders
The severity distribution parameter placeholders.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.